ThemePatrol class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ThemePatrol
- Mixed-in types
Constructors
- ThemePatrol({Key? key, ThemeData? light, ThemeData? dark, ThemeExtensionIterable? extensions, ThemeExtensionBuilderIterable? extensionsBuilder, ThemeMap themes = const {}, ThemeMode initialMode = ThemeMode.system, String? initialTheme, ThemeModeIcons? modeIcons, ThemeChanged? onAvailableChanged, ThemeChanged? onThemeChanged, ThemeChanged? onModeChanged, ThemeChanged? onColorChanged, ThemeChanged? onChanged, required ThemeBuilder builder, Widget? child})
-
themesis optional, it determine the map of ThemeConfig that will be available to select. if one oflightanddarkis provided, will create new theme called 'default' and merged tothemes. AssertionError will be thrown if thethemesis empty.
Properties
- builder → ThemeBuilder
-
Builder that gets called when the theme changes
final
- child → Widget?
-
The widget below this widget in the tree
final
- controller → ThemeController
-
Manages available and selected theme, also notifies listeners of changes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → ThemeController - The ThemeController from the closest instance of this class that encloses the given context.